DrawingRectangle class
- Annotations
-
- @JsonSerializable.new()
Constructors
- DrawingRectangle({required Point2d topLeft, required Point2d bottomRight, String? recognizedText, String? label})
-
DrawingRectangle.fromJson(Map<
String, dynamic> json) -
factory
Properties
- bottomRight ↔ Point2d
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- label ↔ String?
-
getter/setter pair
- recognizedText ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- topLeft ↔ Point2d
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJsonString(
String content) → DrawingRectangle